from PySide6.QtGui import QGuiApplication, QAction
from PySide6.QtQml import QQmlApplicationEngine
from PySide6.QtWidgets import QHBoxLayout, QVBoxLayout, QLabel, QWidget, QMenu, QSizePolicy, QLayout

from models.book import BookStatusEnum

from models.book_overview import BooksOverview

STATUS_TO_COLOR_MAP = {
    BookStatusEnum.available: "#3c702e",
    BookStatusEnum.borrowed: "#702525",
    BookStatusEnum.reserved: "#bc7613"
}
class BookCard(QWidget):
    def __init__(self, book_overview: BooksOverview):
        super().__init__()

        # Create the layout for the card
        layout = QHBoxLayout(self)
        layout.setSizeConstraint(QLayout.SizeConstraint.SetMinimumSize)  # Ensure minimum size is respected
        self.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Fixed)  # Avoid vertical stretching

        layout.setContentsMargins(10, 10, 10, 10)  # Optional: Add margins for spacing
        layout.setSpacing(10)

        # Left-side content
        left_side = QVBoxLayout()
        layout.addLayout(left_side)
        title_label = QLabel(book_overview.title)
        author_label = QLabel("By: " + book_overview.author_name)
        isbn_label = QLabel("ISBN: " + (book_overview.isbn or "Not Available"))
        left_side.addWidget(title_label)
        left_side.addWidget(author_label)
        left_side.addWidget(isbn_label)

        # Right-side content
        right_side = QVBoxLayout()
        layout.addLayout(right_side)
        status_label = QLabel(str(book_overview.status))
        status_label.setStyleSheet(f"color: {STATUS_TO_COLOR_MAP[book_overview.status]}")
        right_side.addWidget(status_label)

        if book_overview.librarian_name and book_overview.borrower_name:
            borrower_label = QLabel("Borrowed: " + book_overview.borrower_name)
            librarian_label = QLabel("By: " + book_overview.librarian_name)
            right_side.addWidget(borrower_label)
            right_side.addWidget(librarian_label)

        self.setLayout(layout)


    def contextMenuEvent(self, event):
        """Override to create a custom right-click menu."""
        context_menu = QMenu(self)

        # Add actions to the menu
        action_edit_book = context_menu.addAction("Edit Book")
        action_edit_author = context_menu.addAction("Edit Author")
        action_mark_returned = context_menu.addAction("Mark as Returned")

        # Execute the menu and get the selected action
        action = context_menu.exec_(self.mapToGlobal(event.pos()))
        if action == action_edit_book:
            self.label.setText("Edit Book selected")
        elif action == action_edit_author:
            self.label.setText("Edit Author selected")
        elif action == action_mark_returned:
            self.label.setText("Mark as Returned selected")