import logging

from mysql.connector import connect, cursor

from utils.config import DatabaseConfig
from utils.errors.database_config_error import DatabaseConfigError


class DatabaseManager():
    def __init__(self) -> None:
        self.logger = logging.getLogger(__name__)
        self.logger.info("Reading database config")
        self.database_config = DatabaseConfig()
        self.connection = connect(
            host=self.database_config.host,
            port=self.database_config.port,
            database=self.database_config.name,
            user=self.database_config.user,
            password=self.database_config.password
        )

    def get_cursor(self) -> cursor.MySQLCursorAbstract:
        return self.connection.cursor(dictionary=True)

    def cleanup(self) -> None:
        self.logger.debug("Closing connection")
        self.connection.close()
